@@ -8,7 +8,7 @@ This is a simple example of the use of the arrowline function.
 
 import displayio
 import board
-from arrowline import line_arrow
+from arrowline import Line
 
 
 display = board.DISPLAY
@@ -28,8 +28,8 @@ screen_tilegrid = displayio.TileGrid(
 
 my_group.append(screen_tilegrid)
 
-line = line_arrow(screen_tilegrid, 40, 90, 90, 60, 12, screen_palette, 1)
-my_group.append(line)
+line = Line(screen_tilegrid, 40, 90, 90, 60, 12, screen_palette, 1)
+my_group.append(line.draw)
 display.show(my_group)
 
 while True:
